package org.ioc.commons.flowcontrol;

import org.ioc.commons.flowcontrol.actioncontroller.ActionController;
import org.ioc.commons.flowcontrol.actioncontroller.IsExternalAction;
import org.ioc.commons.flowcontrol.eventbus.EventBus;
import org.ioc.commons.flowcontrol.eventbus.IsEvent;
import org.ioc.commons.flowcontrol.operationmanager.IsOperation;
import org.ioc.commons.flowcontrol.operationmanager.OperationManager;

/**
 * It represents elements which have the three main components for managing the
 * flow control: Event bus, operation manager and action controller.
 * 
 * @author Jesús Lunar Pérez
 * 
 * @param <E>	Event type
 * @param <O>	Operation type
 * @param <A>	Action type
 */
public interface HasFlowControl<E extends Enum<? extends IsEvent>, O extends Enum<? extends IsOperation>, A extends Enum<? extends IsExternalAction>> {
	/**
	 * 
	 * @return An event bus
	 */
	EventBus<E> eventBus();

	/**
	 * 
	 * @return An operation manager
	 */
	OperationManager<O> operationManager();

	/**
	 * 
	 * @return An action controller
	 */
	ActionController<A> actionController();
}
