package org.ioc.commons.flowcontrol.operationmanager;

import org.ioc.commons.flowcontrol.common.BindRegistration;

/**
 * Binder for operations
 * 
 * @author Jesús Lunar Pérez
 * 
 * @param <O>
 *            Operation type
 */
public interface OperationManagerBinder<O extends Enum<? extends IsOperation>> {
	/**
	 * Binds an operation
	 * 
	 * @param operation
	 *            Operation
	 * @param handler
	 *            Handler which will process the beginning and the end of the
	 *            operation
	 * @return A bind registration object for managing the new binding
	 *         registered.
	 */
	BindRegistration bindOperation(O operation, OperationHandler<O> handler);

	/**
	 * Binds an operation and automatically unbind it when it finishes.
	 * 
	 * @param operation
	 *            Operation
	 * @param handler
	 *            Handler which will process the beginning and the end of the
	 *            operation
	 * @return A bind registration object for managing the new binding
	 *         registered.
	 */
	BindRegistration bindOperationOnce(O operation, OperationHandler<O> handler);

	/**
	 * Binding for all operations. The handler will be fired when the first
	 * operation begins running and when the last operation ends.
	 * 
	 * @param handler
	 *            Handler which will process the beginning and the end of the
	 *            first and last operations.
	 * @return A bind registration object for managing the new binding
	 *         registered.
	 */
	BindRegistration bindOperationsRunning(OperationHandler<O> handler);

	/**
	 * 
	 * @return Number of pending operations
	 */
	int getPendingOps();

	/**
	 * 
	 * @return true if there is any pending operation; false otherwise
	 */
	boolean isBusy();

	/**
	 * 
	 * @param operation
	 * @return true if the operations passed as parameter is being executing or
	 *         not.
	 */
	boolean isOpPending(O operation);
}
