package org.ioc.commons.flowcontrol.operationmanager;

/**
 * Trigger for operations
 * 
 * @author Jesús Lunar Pérez
 * 
 * @param <O>
 */
public interface OperationManagerTrigger<O extends Enum<? extends IsOperation>> {
	/**
	 * Indicates that an operation is being begun
	 * 
	 * @param operation
	 *            The operation
	 */
	void operationBeginning(O operation);

	/**
	 * Indicates that an operation has finished
	 * 
	 * @param operation
	 *            The operation
	 * @param success
	 *            true if the operation finished successfuly; false otherwise
	 * 
	 * @return true if operation was begun; false otherwise.
	 */
	boolean operationFinished(O operation, boolean success);
}
