package org.ioc.commons.flowcontrol.taskcontroller;

/**
 * The task controller is used to manage the execution of separated portion of
 * code depending on the invoked method.
 * 
 * @author Jesús Lunar Pérez
 * 
 */
public interface TaskController {
	/**
	 * Starts a task after a time.
	 * 
	 * @param delayMilis
	 *            Time delayed before starting the task.
	 * 
	 * @param task
	 *            The task to be executed.
	 * 
	 * @return Handler.
	 */
	TaskHandler scheduleDelayed(int delayMilis, Task task);

	/**
	 * Starts a task when system is idle.
	 * 
	 * @param task
	 *            The task to be executed.
	 * 
	 * @return Handler.
	 */
	TaskHandler scheduleIdle(Task task);

	/**
	 * Starts a task when system is idle, and will be repeated until the run()
	 * method returns false.
	 * 
	 * @param task
	 *            The task to be executed.
	 * @return Handler.
	 */
	TaskHandler scheduleIdle(RepeatingTask task);

	/**
	 * Starts a task JUST BEFORE system becomes idle. That is, the last task
	 * executed before the system is idle.
	 * 
	 * @param task
	 *            The task to be executed.
	 * 
	 * @return Handler.
	 */
	TaskHandler scheduleFinally(Task task);

	/**
	 * Starts a task JUST BEFORE system becomes idle and will be repeated until
	 * the run() method returns false.
	 * 
	 * @param task
	 *            The task to be executed.
	 * 
	 * @return Handler.
	 */
	TaskHandler scheduleFinally(RepeatingTask task);

	/**
	 * Runs a task asynchronously
	 * 
	 * @param task
	 *            The task to be executed.
	 * 
	 * @return Handler.
	 */
	TaskHandler runAsync(Task task);
}
