package org.ioc.commons.integration.dataaccess.dao;

/**
 * Handler for a subscripted change performed on an entity
 * 
 * @author Jesús Lunar Pérez
 * 
 * @param <I>
 */
public interface SubscriptionChangeHandler<I> {
	/**
	 * Type of subscriptable changes on an entity
	 * 
	 * @author Jesús Lunar Pérez
	 * 
	 */
	public enum ChangeType {
		/**
		 * Notifies when an entity has been persisted
		 */
		Persisted,
		/**
		 * Notifies when an entity has been updated
		 */
		Updated,
		/**
		 * Notifies when an entity has been deleted
		 */
		Deleted
	}

	/**
	 * Method which will be called when a subscribed change has occurred.
	 * 
	 * @param sender
	 *            Sender for the change
	 * @param id
	 *            Unique identifier of the entity which has been changed.
	 * @param changeType
	 *            Type of change occurred.
	 */
	void handleSubscription(Object sender, I id, ChangeType changeType);

}
